#!/bin/bash
set -euo pipefail

PLAYWRIGHT_VERSION="1.35.0"

pushd "$VENV_PATH" || exit 1
bin/pip install "playwright==$PLAYWRIGHT_VERSION"
popd
